aboutsummaryrefslogtreecommitdiffstats
path: root/dcae-analytics-model/src/main/java/org/openecomp/dcae/apod/analytics/model/domain/cef/CommonEventHeader.java
diff options
context:
space:
mode:
Diffstat (limited to 'dcae-analytics-model/src/main/java/org/openecomp/dcae/apod/analytics/model/domain/cef/CommonEventHeader.java')
-rw-r--r--dcae-analytics-model/src/main/java/org/openecomp/dcae/apod/analytics/model/domain/cef/CommonEventHeader.java92
1 files changed, 78 insertions, 14 deletions
diff --git a/dcae-analytics-model/src/main/java/org/openecomp/dcae/apod/analytics/model/domain/cef/CommonEventHeader.java b/dcae-analytics-model/src/main/java/org/openecomp/dcae/apod/analytics/model/domain/cef/CommonEventHeader.java
index 7cc45d7..b3d625f 100644
--- a/dcae-analytics-model/src/main/java/org/openecomp/dcae/apod/analytics/model/domain/cef/CommonEventHeader.java
+++ b/dcae-analytics-model/src/main/java/org/openecomp/dcae/apod/analytics/model/domain/cef/CommonEventHeader.java
@@ -1,21 +1,21 @@
/*
- * ===============================LICENSE_START======================================
- * dcae-analytics
+ * ============LICENSE_START=========================================================
+ * dcae-analytics
* ================================================================================
- * Copyright © 2017 AT&T Intellectual Property. All rights reserved.
+ * Copyright © 2017 AT&T Intellectual Property. All rights reserved.
* ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * You may obtain a copy of the License at
*
- * http://www.apache.org/licenses/LICENSE-2.0
+ * http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
- * ============================LICENSE_END===========================================
+ * ============LICENSE_END=========================================================
*/
package org.openecomp.dcae.apod.analytics.model.domain.cef;
@@ -26,7 +26,7 @@ import lombok.EqualsAndHashCode;
/**
* Fields common to all Events
* <p>
- * @author Rajiv Singla . Creation Date: 10/17/2016.
+ * @author Rajiv Singla. Creation Date: 08/15/2017.
*/
@Data
@EqualsAndHashCode(callSuper = true)
@@ -41,7 +41,7 @@ public class CommonEventHeader extends BaseCEFModel {
* @param domain New value for domain
* @return The eventing domain associated with this event
*/
- private String domain;
+ private Domain domain;
/**
* Event key that is unique to the event source
@@ -52,12 +52,30 @@ public class CommonEventHeader extends BaseCEFModel {
private String eventId;
/**
- * Function of the source e.g. eNodeB, MME, PCRF
+ * Unique event name
*
- * @param functionalRole New value for functional Role
- * @return Function of the source e.g. eNodeB, MME, PCRF
+ * @param eventName New value for event name
+ * @return Unique event name
*/
- private String functionalRole;
+ private String eventName;
+
+
+ /**
+ * Event type e.g. applicationVnf, guestOS, hostOS, platform
+ *
+ * @param eventType New value for event type
+ * @return Event type e.g. applicationVnf, guestOS, hostOS, platform
+ */
+ private String eventType;
+
+
+ /**
+ * Enrichment fields for internal VES Event Listener service use only, not supplied by event sources
+ *
+ * @param internalHeaderFields new value for internal Header Fields
+ * @return Enrichment fields for internal VES Event Listener service use only, not supplied by event sources
+ */
+ private InternalHeaderFields internalHeaderFields;
/**
@@ -71,6 +89,24 @@ public class CommonEventHeader extends BaseCEFModel {
/**
+ * Three character network function component type as aligned with vfc naming standards
+ *
+ * @param nfcNamingCode New value for nfc naming code
+ * @return Three character network function component type as aligned with vfc naming standards
+ */
+ private String nfcNamingCode;
+
+
+ /**
+ * Four character network function type as aligned with vnf naming standards
+ *
+ * @param nfNamingCode New value for nf naming code
+ * @return Four character network function type as aligned with vnf naming standards
+ */
+ private String nfNamingCode;
+
+
+ /**
* Processing Priority
*
* @param priority New value for processing Priority
@@ -80,10 +116,20 @@ public class CommonEventHeader extends BaseCEFModel {
/**
- * Name of the entity reporting the event, for example, an OAM VM
+ * UUID identifying the entity reporting the event, for example an OAM VM; must be populated by the
+ * enrichment process
+ *
+ * @param reportingEntityId New value for reporting entity Id. Must be populated by the enrichment process
+ * @return UUID identifying the entity reporting the event populated by the enrichment process
+ */
+ private String reportingEntityId;
+
+
+ /**
+ * Name of the entity reporting the event, for example, an EMS name; may be the same as sourceName
*
* @param reportingEntityName New value for reporting Entity Name
* @return Name of the entity reporting the event, for example, an OAM VM
*/
private String reportingEntityName;
@@ -98,6 +144,15 @@ public class CommonEventHeader extends BaseCEFModel {
/**
+ * UUID identifying the entity experiencing the event issue; must be populated by the enrichment process
+ *
+ * @param sourceId New value for source id. Must be populated by the enrichment process
+ * @return UUID identifying the entity experiencing the event issue
+ */
+ private String sourceId;
+
+
+ /**
* Name of the entity experiencing the event issue
*
* @param sourceName New value for source name
@@ -114,4 +169,13 @@ public class CommonEventHeader extends BaseCEFModel {
* @return The earliest unix time associated with the event from any component
*/
private Long startEpochMicrosec;
+
+
+ /**
+ * Version of the event header
+ *
+ * @param version New value for version of the event header
+ * @return Version of the event header
+ */
+ private Float version;
}
@@ -80,10 +116,20 @@ public class CommonEventHeader extends BaseCEFModel {
*
* @param reportingEntityName New value for reporting Entity Name
- * @return Name of the entity reporting the event, for example, an OAM VM
+ * @return Name of the entity reporting the event, may be the same as sourceName
*/
private String reportingEntityName;